@@ -42,7 +42,7 @@ visConfigure <- function(graph,
   if(any(class(graph) %in% "visNetwork_Proxy")){
     options <- list(configure = configure)
     data <- list(id = graph$id, options = options)
-    graph$session$sendCustomMessage("Options",data)
+    graph$session$sendCustomMessage("visShinyOptions",data)
   }else{
     graph$x$options$configure <- configure
   }
