@@ -18,7 +18,7 @@
 #' @param mass : Number. Default to 1. The barnesHut physics model (which is enabled by default) is based on an inverted gravity model. By increasing the mass of a node, you increase it's repulsion. Values lower than 1 are not recommended.
 #' @param physics : Boolean. Default to true. When false, the node is not part of the physics simulation. It will not move except for from manual dragging.
 #' @param borderWidth : Number. Default to 1. The width of the border of the node when it is not selected, automatically limited by the width of the node.
-#' @param borderWidthSelected : Number. Undefined. The width of the border of the node when it is selected. If left at undefined, double the borderWidth will be used.
+#' @param borderWidthSelected : Number. Default to 2. The width of the border of the node when it is selected. If left at undefined, double the borderWidth will be used.
 #' @param brokenImage : String. Undefined. When the shape is set to image or circularImage, this option can be an URL to a backup image in case the URL supplied in the image option cannot be resolved
 #' @param labelHighlightBold : Boolean. Default to true. Determines whether or not the label becomes bold when the node is selected.
 #' @param color : String | named list.	Color for the node. Can be just one color, or a list with several elements :
@@ -38,7 +38,7 @@
 #'    }
 #'  }
 #'}
-#' @param fixed : Boolean | named list. Default to false. When true, the node will not move but IS part of the physics simulation. When defined as an lisl, movement in either X or Y direction can be disabled.
+#' @param fixed : Boolean | named list. Default to false. When true, the node will not move but IS part of the physics simulation. When defined as an list, movement in either X or Y direction can be disabled.
 #' \itemize{
 #'  \item{"x"}{ : Boolean. When true, the node will not move in the X direction.}
 #'  \item{"y"}{ : Boolean. When false, the node will not move in the X direction.}
@@ -91,6 +91,7 @@
 #' \itemize{
 #'  \item{"borderDashes"}{ : Vector or Boolean. Default to	false. This property applies to all shapes that have borders. You set the dashes by supplying an Vector Vector formart: [dash length, gap length]. You can also use a Boolean, false is disable and true is default [5,15].}
 #'  \item{"borderRadius"}{ : Number. Default to	6. This property is used only for the box shape. It allows you to determine the roundness of the corners of the shape.}
+#'  \item{"interpolation"}{ : 	Boolean. Default to	true. This property only applies to the image and circularImage shapes. When true, the image is resampled when scaled down, resulting in a nicer image at the cost of computional time.}
 #'  \item{"useImageSize"}{ : Boolean. Default to false. This property only applies to the image and circularImage shapes. When false, the size option is used, when true, the size of the image is used.}
 #'  \item{"useBorderWithImage"}{ : Boolean. Default to false. This property only applies to the image shape. When true, the color object is used. A rectangle with the background color is drawn behind it and it has a border. This means all border options are taken into account.}
 #'}
@@ -189,7 +190,7 @@ visNodes <- function(graph,
   if(any(class(graph) %in% "visNetwork_Proxy")){
     options <- list(nodes = nodes)
     data <- list(id = graph$id, options = options)
-    graph$session$sendCustomMessage("Options",data)
+    graph$session$sendCustomMessage("visShinyOptions",data)
   }else{
     graph$x$options$nodes <- mergeLists(graph$x$options$nodes, nodes)
   }
