@@ -22,12 +22,12 @@
 visRedraw <- function(graph){
   
   if(!any(class(graph) %in% "visNetwork_Proxy")){
-    stop("Can't use visFit with visNetwork object. Only within shiny & using visNetworkProxy")
+    stop("Can't use visRedraw with visNetwork object. Only within shiny & using visNetworkProxy")
   }
   
   data <- list(id = graph$id)
   
-  graph$session$sendCustomMessage("Redraw", data)
+  graph$session$sendCustomMessage("visShinyRedraw", data)
   
   graph
 }
